Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetNumPages ¶
GetNumPages will try to get actual document page count by converting the document to a PDF first and then get the actual page count from the PDF result.
WARNING: This method is currently in experimental state as the PDF result might have incorrect page count.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.